Struct Irqraw
#[repr(transparent)]pub struct Irqraw(pub u32);Expand description
IRQRAW register.
Tuple Fields
0: u32Implementations
impl Irqraw
impl Irqraw
pub const fn cmddone_ris(&self) -> bool
pub const fn cmddone_ris(&self) -> bool
Command done raw/unmasked interrupt status. This it is set once the requested command execution is completed. Cleared by writing 1.
pub fn set_cmddone_ris(&mut self, val: bool)
pub fn set_cmddone_ris(&mut self, val: bool)
Command done raw/unmasked interrupt status. This it is set once the requested command execution is completed. Cleared by writing 1.
pub const fn cmdstart_ris(&self) -> bool
pub const fn cmdstart_ris(&self) -> bool
Command started raw/unmasked interrupt status. This bit is set once the requested command execution has started.
pub fn set_cmdstart_ris(&mut self, val: bool)
pub fn set_cmdstart_ris(&mut self, val: bool)
Command started raw/unmasked interrupt status. This bit is set once the requested command execution has started.
pub const fn cmderr_ris(&self) -> bool
pub const fn cmderr_ris(&self) -> bool
Command error raw/unmasked interrupt status.
pub fn set_cmderr_ris(&mut self, val: bool)
pub fn set_cmderr_ris(&mut self, val: bool)
Command error raw/unmasked interrupt status.
pub const fn illcmd_ris(&self) -> bool
pub const fn illcmd_ris(&self) -> bool
Illegal command raw/unmasked interrupt status.
pub fn set_illcmd_ris(&mut self, val: bool)
pub fn set_illcmd_ris(&mut self, val: bool)
Illegal command raw/unmasked interrupt status.
pub const fn readok_ris(&self) -> bool
pub const fn readok_ris(&self) -> bool
Mass read OK raw/unmasked interrupt status.
pub fn set_readok_ris(&mut self, val: bool)
pub fn set_readok_ris(&mut self, val: bool)
Mass read OK raw/unmasked interrupt status.
pub const fn cmdsleeperr_ris(&self) -> bool
pub const fn cmdsleeperr_ris(&self) -> bool
(1: active, 0: inactive) COMMAND issued while flash in sleep-mode (SLM=1).
pub fn set_cmdsleeperr_ris(&mut self, val: bool)
pub fn set_cmdsleeperr_ris(&mut self, val: bool)
(1: active, 0: inactive) COMMAND issued while flash in sleep-mode (SLM=1).